@@ -57,4 +57,10 @@
     --- 修复 TitleBar 类在mac下图标显示位置的问题
     --- utility.py 新增 系统判断
     --- 新增状态栏
+    --- 状态栏 新增 setStatusPos() 方法
+2023.1.5 0.0.8.3版本
+    --- 优化 TitleBar,StatusBar 代码,并修复了样式表设置无效的BUG
+2023.1.5 1.0.8.3版本
+    --- 新增 styles 皮肤包项目 
+    --- 全面兼容 PyQt5,PyQt6,PySide2,PySide6, PySide6 在使用无边框的还有小问题
 '''
\ No newline at end of file
