@@ -1,5 +1,5 @@
-
 from PyQtGuiLib.header import (
+    PYQT_VERSIONS,
     QApplication,
     QWidget,
     QFrame,
@@ -14,11 +14,15 @@ from PyQtGuiLib.header import (
     QPropertyAnimation,
     QParallelAnimationGroup,
     QBrush,
-    Qt,
+    qt,
     QSize,
     QPoint,
     QPixmap,
-    QIcon
+    QIcon,
+    QStyle,
+    QStyleOption,
+    desktopCenter,
+    desktopSize
 )
 
 '''
@@ -71,7 +75,8 @@ class ButtonIcon(QPushButton):
 
     def paintEvent(self, event: QPaintEvent) -> None:
         painter = QPainter(self)
-        painter.setRenderHints(painter.Antialiasing | painter.SmoothPixmapTransform | painter.TextAntialiasing)
+        painter.setRenderHints(qt.Antialiasing | qt.SmoothPixmapTransform | qt.TextAntialiasing)
+
 
         self.drawIcon(painter)
 
@@ -103,7 +108,7 @@ class ZoomButton(ButtonIcon):
             op.setColor(QColor(50, 100, 100))
             painter.setPen(op)
             painter.drawLine(5, self.height() // 2, self.width() - 5, self.height() // 2)
-            painter.setBrush(Qt.NoBrush)
+            painter.setBrush(qt.NoBrush)
 
 
 # 放大按钮
@@ -138,7 +143,7 @@ class LargeButton(ButtonIcon):
             painter.drawEllipse(self.width()//2-5,self.height()//2-5,5,5)
             painter.drawEllipse(self.width()//2+1,self.height()//2+1,5,5)
 
-            painter.setBrush(Qt.NoBrush)
+            painter.setBrush(qt.NoBrush)
 
 
 # 关闭按钮
@@ -173,7 +178,7 @@ class CloseButton(ButtonIcon):
             painter.drawLine(self.width() - 5, 5, 5, self.height() - 5)
 
 
-class TitleBar(QFrame):
+class TitleBar(QWidget):
 
     # 标题的位置
     Title_Left = "TextLeft"
@@ -397,9 +402,9 @@ class TitleBar(QFrame):
                 self.old_screen_geometry = self.__parent.geometry()  # type:QRect
 
                 # 获取的单个屏幕的大小
-                single_screen_width = QApplication.desktop().size().width() // QApplication.desktop().screenCount()
-                single_screen_height = QApplication.desktop().size().height()
-                animation.setEndValue(QSize(single_screen_width,single_screen_height))
+                # single_screen_width = QApplication.desktop().size().width() // QApplication.desktop().screenCount()
+                # single_screen_height = QApplication.desktop().size().height()
+                animation.setEndValue(desktopSize())
                 #
                 animation_move.setEndValue(QPoint(0,0))
 
@@ -438,4 +443,11 @@ class TitleBar(QFrame):
         occ_w = occ_w+self.zm.width()+btn_w_interval
         self.lm.move(occ_w,lm_h)
         occ_w  = occ_w+self.lm.width()+btn_w_interval
-        self.cm.move(occ_w,cm_h)
\ No newline at end of file
+        self.cm.move(occ_w,cm_h)
+
+    def paintEvent(self, e: QPaintEvent) -> None:
+        opt = QStyleOption()
+        opt.initFrom(self)
+
+        painter = QPainter(self)
+        self.style().drawPrimitive(qt.PE_Widget,opt,painter,self)
\ No newline at end of file
