@@ -23,7 +23,7 @@ if PYQT_VERSIONS == "PyQt5":
         QSplitter,
         QGraphicsOpacityEffect,
         QMainWindow,
-        QDesktopWidget,
+        QDesktopWidget as DesktopWidget,
         QGraphicsDropShadowEffect,
         QSlider,
         QListWidget,
@@ -33,9 +33,10 @@ if PYQT_VERSIONS == "PyQt5":
         QAbstractScrollArea,
         QRadioButton,
         QSpacerItem,
-        QSizePolicy
+        QSizePolicy,
+        QStyle,
+        QStyleOption
     )
-
 if PYQT_VERSIONS == "PyQt6":
     from PyQt6.QtWidgets import (
         QApplication,
@@ -60,17 +61,17 @@ if PYQT_VERSIONS == "PyQt6":
         QSplitter,
         QGraphicsOpacityEffect,
         QMainWindow,
-        QDesktopWidget,
         QGraphicsDropShadowEffect,
         QSlider,
         QListWidget,
         QListWidgetItem,
         QListView,
-        QAction,
         QAbstractScrollArea,
         QRadioButton,
         QSpacerItem,
-        QSizePolicy
+        QSizePolicy,
+        QStyle,
+        QStyleOption
 )
 
 if PYQT_VERSIONS == "PySide2":
@@ -97,7 +98,7 @@ if PYQT_VERSIONS == "PySide2":
         QSplitter,
         QGraphicsOpacityEffect,
         QMainWindow,
-        QDesktopWidget,
+        QDesktopWidget as DesktopWidget,
         QGraphicsDropShadowEffect,
         QSlider,
         QListWidget,
@@ -107,7 +108,9 @@ if PYQT_VERSIONS == "PySide2":
         QAbstractScrollArea,
         QRadioButton,
         QSpacerItem,
-        QSizePolicy
+        QSizePolicy,
+        QStyle,
+        QStyleOption
     )
 
 if PYQT_VERSIONS == "PySide6":
@@ -134,15 +137,15 @@ if PYQT_VERSIONS == "PySide6":
         QSplitter,
         QGraphicsOpacityEffect,
         QMainWindow,
-        QDesktopWidget,
         QGraphicsDropShadowEffect,
         QSlider,
         QListWidget,
         QListWidgetItem,
         QListView,
-        QAction,
         QAbstractScrollArea,
         QRadioButton,
         QSpacerItem,
-        QSizePolicy
+        QSizePolicy,
+        QStyle,
+        QStyleOption
     )
\ No newline at end of file
