@@ -36,8 +36,8 @@ border-radius:30px;
 }
         ''')
         self.tbar = TitleBar(self)
-        # self.tbar.setTitleText("测试标题栏")
-        self.tbar.setTitleIcon(r"/Applications/Python 3.8/save/PyQtGuiLib/PyQtGuiLib/tests/image/1.png")
+        self.tbar.setTitleText("测试标题栏")
+        # self.tbar.setTitleIcon(r"/Applications/Python 3.8/save/PyQtGuiLib/PyQtGuiLib/tests/image/1.png")
         self.tbar.setTitlePos(TitleBar.Title_Center)
         self.tbar.setBtnStyle(TitleBar.MacStyle)
         self.tbar.setStyleSheet("background-color: rgb(232, 232, 232);")
@@ -51,7 +51,7 @@ if __name__ == '__main__':
     win = TestTitleBar()
     win.show()
 
-    if PYQT_VERSIONS == "PyQt6":
+    if PYQT_VERSIONS in ["PyQt6","PySide6"]:
         sys.exit(app.exec())
     else:
         sys.exit(app.exec_())
\ No newline at end of file
